mlbench_core.optim
------------------

.. autoapimodule:: mlbench_core.optim
.. currentmodule:: mlbench_core.optim


pytorch
~~~~~~~
.. autoapimodule:: mlbench_core.optim.pytorch
.. currentmodule:: mlbench_core.optim.pytorch


optim
+++++
.. autoapimodule:: mlbench_core.optim.pytorch.optim
.. currentmodule:: mlbench_core.optim.pytorch.optim


SparsifiedSGD
'''''''''''''

.. autoapiclass:: SparsifiedSGD
    :members:

CentralizedSparsifiedSGD
''''''''''''''''''''''''

.. autoapiclass:: CentralizedSparsifiedSGD
    :members:

DecentralizedSGD
''''''''''''''''

.. autoapiclass:: DecentralizedSGD
    :members:

CentralizedSGD
''''''''''''''

.. autoapiclass:: CentralizedSGD
    :members:

SignSGD
'''''''

.. autoapiclass:: SignSGD
    :members:

CentralizedAdam
'''''''''''''''

.. autoapiclass:: CentralizedAdam
    :members:
